@@ -7,22 +7,22 @@ tests.test_cache
 Provides unit tests.
 """
 
-import time
 import random
+import time
+
 import pytest
 
 from mezmorize import Cache, function_namespace
-from mezmorize.utils import HAS_MEMCACHE, HAS_REDIS, get_cache_config
-
 from mezmorize.backends import (
-    SimpleCache,
-    FileSystemCache,
-    RedisCache,
-    MemcachedCache,
-    SASLMemcachedCache,
-    SpreadSASLMemcachedCache,
     AVAIL_MEMCACHES,
+    FileSystemCache,
+    MemcachedCache,
+    RedisCache,
+    SASLMemcachedCache,
+    SimpleCache,
+    SpreadSASLMemcachedCache,
 )
+from mezmorize.utils import HAS_MEMCACHE, HAS_REDIS, get_cache_config
 
 BIGINT = 2**21
 BIGGERINT = 2**28
@@ -503,12 +503,19 @@ class TestFileSystemCache(TestCache):
         check_cache_type(fs_client.cache, "filesystem")
         check_cache_instance(fs_client.cache, FileSystemCache)
 
-    def test_add_bytes(self, fs_client):
-        fs_client.cache.add(b"hi", "hello")
-        assert fs_client.cache.get(b"hi") == "hello"
+    def test_add(self, fs_client):
+        fs_client.cache.add("hi", "hello")
+        assert fs_client.cache.get("hi") == "hello"
 
-        fs_client.cache.add(b"hi", b"foobar")
-        assert fs_client.cache.get(b"hi") == "hello"
+        fs_client.cache.add("hi", "foobar")
+        assert fs_client.cache.get("hi") == "hello"
+
+    def test_add_unicode(self, fs_client):
+        fs_client.cache.add("ȟį", "ƕɛĺłö")
+        assert fs_client.cache.get("ȟį") == "ƕɛĺłö"
+
+        fs_client.cache.add("ȟį", "fööƀåř")
+        assert fs_client.cache.get("ȟį") == "ƕɛĺłö"
 
 
 if HAS_MEMCACHE:
@@ -561,10 +568,14 @@ if HAS_REDIS:
             check_cache_instance(redis_client.cache, RedisCache)
 
         def test_add_bytes(self, redis_client):
-            pass
+            redis_client.cache.add(b"hi", b"hello")
+            assert redis_client.cache.get(b"hi") == b"hello"
+
+            redis_client.cache.add(b"hi", b"foobar")
+            assert redis_client.cache.get(b"hi") == b"hello"
 
         def test_delete_bytes(self, redis_client):
-            pass
+            check_set_delete(redis_client.cache, b"hi", b"hello")
 
         def test_redis_url_default_db(self, redis_client):
             client = redis_client.cache.cache._client
